Crate sif_parser

Crate sif_parser 

Re-exports

pub use error::Error;
pub use error::ErrorKind;
pub use error::Pos;
pub use types::Block;
pub use types::BlockType;
pub use types::CdcOp;
pub use types::Directive;
pub use types::Document;
pub use types::Event;
pub use types::FieldDef;
pub use types::FieldRef;
pub use types::Header;
pub use types::Modifier;
pub use types::Record;
pub use types::Schema;
pub use types::Section;
pub use types::SortDirection;
pub use types::Span;
pub use types::Template;
pub use types::Type;
pub use types::Value;
pub use infer::from_csv;
pub use infer::from_json;
pub use infer::from_jsonl;
pub use infer::to_csv;
pub use infer::to_json_array;
pub use infer::to_jsonl;
pub use infer::infer_schema;
pub use infer::infer_schema_owned;
pub use infer::infer_type;
pub use infer::merge_types;
pub use infer::sanitize_field_name;
pub use streaming::StatusLevel;
pub use streaming::StreamEvent;
pub use streaming::StreamInfo;
pub use streaming::StreamMode;
pub use streaming::StreamReader;

Modules

error
infer
packed
streaming
types

Structs

Emitter
A SIF document emitter.
Reader
A streaming, event-based SIF reader.

Functions

emit_to_string
Convenience: emit a document to a String.
parse
Parse a complete SIF document from a string.
parse_inline_annotations
Parse inline semantic annotations in a string (16.3).
parse_inline_sif
Parse an inline SIF expression (21): sif::#schema ...::record::record.
parse_schema
Parse a #schema field-definition list (without the #schema prefix).
parse_type_str
Parse a SIF type string (e.g., "str[]?", "enum(a,b,c)").
parse_typed_value
Parse a single field value according to a declared type.
parse_untyped_value
Parse a single field value using untyped disambiguation (9.2).
reader_stdin
Create a reader from stdin.