Module packed

Module packed 

Enums

PackedWidth
Packed width override from field modifiers.

Constants

FRAME_BATCH_INSERT
FRAME_BATCH_UPDATE
FRAME_DELETE
FRAME_INSERT
Frame marker bytes per the spec.
FRAME_UPDATE

Functions

decode_batch_frame
Decode a batch frame into records.
decode_record_frame
Decode a record from a packed binary frame payload.
decode_value
Decode a single SIF value from packed binary. Returns (Value, bytes_consumed).
decode_varint
Decode an unsigned LEB128 varint from a byte slice. Returns (value, bytes_consumed).
encode_batch_frame
Encode a batch of records into a batch frame.
encode_record_frame
Encode a record to a packed binary frame (marker + length + payload).
encode_value
Encode a single SIF value to packed binary.
encode_varint
Encode an unsigned integer as LEB128 varint.
zigzag_decode
Zigzag decode an unsigned u64 to signed i64.
zigzag_encode
Zigzag encode a signed i64 to unsigned u64.