Module types

Module types 

Structs

Block
A parsed block region (19).
Document
A complete parsed SIF document.
FieldDef
A single field definition within a #schema directive (8).
FieldRef
A reference to a field, optionally in another section.
Header
The parsed header line of a SIF document.
Modifier
A key-value modifier on a field definition (8.6).
Record
A parsed data record.
Schema
A parsed #schema directive (8).
Section
A section within a SIF document.
Template
A named template for record rendering (22).

Enums

BlockType
CdcOp
Change Data Capture operation prefix on a record.
Directive
A parsed meta directive.
Event
Events emitted by the streaming Reader.
SortDirection
Span
A span of text that may contain inline semantic annotations.
Type
SIF type as declared in a #schema directive.
Value
A parsed SIF value.