Enums
- Packed
Width - Packed width override from field modifiers.
Constants
- FRAME_
BATCH_ INSERT - FRAME_
BATCH_ UPDATE - FRAME_
DELETE - FRAME_
INSERT - Frame marker bytes per the spec.
- FRAME_
UPDATE
Functions
- decode_
batch_ frame - Decode a batch frame into records.
- decode_
record_ frame - Decode a record from a packed binary frame payload.
- decode_
value - Decode a single SIF value from packed binary. Returns (Value, bytes_consumed).
- decode_
varint - Decode an unsigned LEB128 varint from a byte slice. Returns (value, bytes_consumed).
- encode_
batch_ frame - Encode a batch of records into a batch frame.
- encode_
record_ frame - Encode a record to a packed binary frame (marker + length + payload).
- encode_
value - Encode a single SIF value to packed binary.
- encode_
varint - Encode an unsigned integer as LEB128 varint.
- zigzag_
decode - Zigzag decode an unsigned u64 to signed i64.
- zigzag_
encode - Zigzag encode a signed i64 to unsigned u64.